unit Vermain;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, StdCtrls, Grids, Utility;

type
  TMainForm = class(TForm)
    GoButton: TButton;
    OpenDialog1: TOpenDialog;
    Grid: TStringGrid;
    MsgLine: TLabel;
    StopButton: TButton;
    ExitButton: TButton;
    Msg2: TLabel;
    Label1: TLabel;
    procedure GoButtonClick(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure StopButtonClick(Sender: TObject);
    procedure ExitButtonClick(Sender: TObject);
  private
    stopPlease:   boolean;
  public
    { Public declarations }
  end;

var
  MainForm: TMainForm;

implementation

{$R *.DFM}

function TUInit ( var SessHandle: THandle ) : integer;
  far; external 'TUTILITY';
function TUExit ( SessHandle: THandle ) : integer;
  far; external 'TUTILITY';
function TUVerifyTable ( SessHandle: THandle;
                         tableName:  PChar;
                         driverType: PChar;
                         errorTable: PChar;
                         password:   PChar;
                         options:    integer;
                         var errorLevel: integer ) : integer;
  far; external 'TUTILITY';

procedure TMainForm.GoButtonClick(Sender: TObject);
const
   VF_APPEND_ERRORS            =  1;
   VF_BYPASS_SECONDARY_INDEXES =  2;
   VF_IGNORE_WARNINGS          =  4;
   VF_VERIFY_HEADER_ONLY       =  8;
   VF_LOCK_TABLE               = 32;

   VF_OPTIONS = VF_IGNORE_WARNINGS + VF_LOCK_TABLE;

var
   sessHandle: THandle;
   inx:        integer;
   goodCount,
   badCount,
   numFiles:   integer;
   rc:         integer;
   errorLevel: integer;
   fileno:     integer;
   verdict:    string[60];
   tableName:  string;
   szTable,
   szDriver,
   szErrorTable,
   szPassword:    array [0..255] of char;
begin
   strPCopy(szDriver,     'PARADOX');
   strPCopy(szErrorTable, '_TUERR');
   strPCopy(szPassword,   '');

   goodCount  := 0;
   badCount   := 0;
   stopPlease := false;

   if openDialog1.Execute then begin
      try
         rc := TUInit(sessHandle);
         if rc >= 0 then begin
            numFiles := openDialog1.Files.Count;
            Grid.RowCount := numFiles + 1;
            for inx := 0 to numFiles - 1 do begin
               tableName := openDialog1.Files[inx];
               Grid.Cells[0, inx+1] := ExtractFileName(tableName);
            end;
            doEvents;

            StopButton.Enabled  := True;
            ExitButton.Enabled  := False;
            GoButton.Enabled    := False;

            for inx := 0 to numFiles - 1 do begin
               tableName := openDialog1.Files[inx];
               strPCopy(szTable, tableName);
               Msg2.Caption    := Format('File %d of %d', [inx+1, numFiles]);
               MsgLine.Caption := Format('Verifying "%s"', [tableName]);
               Grid.Row := inx + 1;
               Hourglass(True);
               doEvents;
               rc := TUVerifyTable(sessHandle,
                                   szTable,
                                   szDriver,
                                   szErrorTable,
                                   szPassword,
                                   VF_OPTIONS,
                                   errorLevel  );
               Hourglass(False);
               doEvents;
               if rc = 0 then begin
                  verdict := 'Okay';
                  Inc(goodCount);
               end else begin
                  Inc(badCount);
                  case errorLevel of
                     0:   verdict := 'Questionable (0)';
                     1:   verdict := 'Damaged (1)';
                     2:   verdict := 'Seriously damaged (2)';
                     3:   verdict := 'Requires manual rebuild (3)';
                     else verdict := Format('Beyond repair (%d)', [errorLevel]);
                  end;
               end;
               Grid.Cells[1, inx+1] := verdict;
               doEvents;
               if stopPlease then abort;
            end; {for}

            rc := TUExit(sessHandle);
            if rc < 0 then begin
               Say(Format('TUExit failed, code = %d', [rc]));
            end;
         end else begin
            Say(Format('TUInit failed, code = %d', [rc]));
         end;
      finally
         if stopPlease then begin
            MsgLine.Caption := 'Cancelled';
         end else begin
            MsgLine.Caption := 'Done';
         end;
         StopButton.Enabled  := false;
         ExitButton.Enabled  := true;
         GoButton.Enabled    := true;
      end;
   end else begin
      Say('No tables selected');
   end; {if anything to do}

   doEvents;
   if badCount = 0 then begin
      Say(Format('%d files processed; no errors.', [goodCount + badCount]));
   end else begin
      Say(Format('%d files processed; %d errors.', [goodCount + badCount, badCount]));
   end;
end;

procedure TMainForm.FormShow(Sender: TObject);
begin
   Grid.Cells[0,0] := 'Table';
   Grid.Cells[1,0] := 'Status';
end;

procedure TMainForm.StopButtonClick(Sender: TObject);
begin
   stopPlease := true;
   StopButton.Enabled := false;
end;

procedure TMainForm.ExitButtonClick(Sender: TObject);
begin
   Close;
end;

end.
